<?php
namespace Modules\Cadastros\Controllers;

use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;

class CadastroUsuarioSupplyTekController {

    private $environment;
    private $entityManager;
    private $service;

    public function __construct ($environment, $entityManager, $service){
    	$this->environment = $environment;
        $this->entityManager = $entityManager;
        $this->service = $service;
    }
    
    public function saveUser($request, $response) {
        try {
            $row = $request->getRow();
            $this->service->insertUserSupplyTek($row);
            if(!empty($row['CDFILIALPADRAO'])) {
                $this->service->saveUnidadePadrao($row);
            }
		} catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
    }
    
    public function deleteUser($request, $response) {
        try {
            $row = $request->getRow();
            $this->service->deleteUserSupplyTek($row);
            
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}   
    }
    
    public function saveAcessoSupply($request, $response)
    {
        try {
            $row = $request->getRow()[0];
            
            $result = $this->service->verifyOperator($row['CDOPERADOR']);
            
            if ($result && $result[0]) {
                if ($result[0]['IDPERFILACES'] == 'GO') {
                    $result = $this->service->verifyUnitFromOperator($row['CDOPERADOR'], $row['CDFILIAL']);
                    
                    if (!$result) {
                        $this->service->addOperator($row);
                    }
                }
            } else {
                $this->service->addOperator($row);
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
    
    }
    
    public function saveMultiploAcessoSupply($request, $response)
    {
        try {
            $rows = $request->getRow();
            
            $array = $this->arrangeArrayMultilpleInsert($rows);
            
            foreach ($array as $cdOperador => $unidades) {
                $result = $this->service->verifyOperator($cdOperador);
                
                if ($result && $result[0]) {
                    if ($result[0]['IDPERFILACES'] == 'GO') {
                        foreach ($unidades as $unidade) {
                            $result = $this->service->verifyUnitFromOperator($cdOperador, $unidade['CDFILIAL']);
                            
                            if (!$result) {
                                $this->service->addOperator($unidade);
                            }
                        }
                    }
                } else {
                    foreach ($unidades as $unidade) {
                        $this->service->addOperator($unidade);
                    }
                }
            }
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}
    }
    
    private function arrangeArrayMultilpleInsert($rows)
    {
        $array = array();
        
        foreach ($rows as $row) {
            $array[$row['CDOPERADOR']][] = $row;
        }
        
        return $array;
    }
    
    public function verificaOperador($request, $response) {
        try {
            $row = $request->getDataSet()->getRows();
            $result = $this->service->selectOperator($row[0]);  
            $response->addDataSet(new DataSet("resp", $result));
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}   
    }
    
    public function updateFilialNaoPadrao($request, $response) {
        try {
            $row = $request->getRow();
            $this->service->updateFilialNaoPadrao($row);
            
        } catch (\Exception $e) {
			$response->setError(new Error($e->getMessage(), 500));
		}   
    }
}