<?php
namespace Modules\Cotacao\Modules\Pedido\Controllers;

use Doctrine\ORM\EntityManager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Util\SupUtilities;

class ControlePedidoColetaInternet extends \Teknisa\GER\Controllers\TeknisaCrud
{

    protected $crudService;
    protected $controlePedidoColetaInternetService;
    protected $controlePedidoColetaAceiteService;
    protected $controlePedidoColetaService;
    protected $dataSourceManager;
    protected $smtpUtil;
    protected $entityManager;
    protected $zhFileUploader;
    protected $fileServerURL;
    protected $supUtilities;
    protected $environment;

    public function __construct($crudService, $parameterBag, $controlePedidoColetaInternetService, $controlePedidoColetaAceiteService, $controlePedidoColetaService, $dataSourceManager, $smtpUtil, EntityManager $entityManager, $zhFileUploader, $fileServerURL, SupUtilities $supUtilities, $environment) 
    {
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->controlePedidoColetaInternetService = $controlePedidoColetaInternetService;
        $this->controlePedidoColetaAceiteService = $controlePedidoColetaAceiteService;
        $this->controlePedidoColetaService = $controlePedidoColetaService;
        $this->dataSourceManager = $dataSourceManager;
        $this->smtpUtil = $smtpUtil;
        $this->entityManager = $entityManager;
        $this->templatesDir = realpath(__DIR__ . '/../../../../../Util/Template');
        $this->zhFileUploader    = $zhFileUploader;
        $this->fileServerURL     = $fileServerURL;
        $this->supUtilities = $supUtilities;
        $this->environment = $environment;
    }
    
    //Atualizacao para Aprovação do Pedido de Coleta em Massa
    public function verificaUtilizaAprovacaoMassa(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        try {
            //Verifica se o operador logado é o que deve aceitar o pedido selecionado
            $eAprovadorAtual = true;
            foreach ($row as $pedido){

               $opAprovAtual = $this->controlePedidoColetaInternetService->selectAprovador( $pedido['CDFILIAL'], $pedido['NRPEDIDOCOL']);
               if($opAprovAtual){
                   if($row[0]['OPERADORLOGADO'] != $opAprovAtual[0]['CDOPERADOR']){
                       $eAprovadorAtual = false;
                   }
               }else{
                   $eAprovadorAtual = false;
               }
                
            }
            
            if(!$eAprovadorAtual){
                $response->addMessage(new DTO\Response\Message('ERROR_APROV_DIF'));
            }else{
            
                //Primeira coisa é ver qual o parâmetro está setado na Tela Dados Fornecedor/Ecommerce no campo Utiliza Aprovação de PedCol em Massa
                //Caso Não - Bloquear Ação se tiver mais de um pedido
                //Caso Apenas Gerentes ou Compradores - Verificar user
                //Caso Ambos - Verificar
                
                
               $paramUsaApMassa = $this->controlePedidoColetaInternetService->selectUtilizaAprovMassa($row[0]['CDFILIAL']);
               
               //$gerente é 1 caso true e 0 caso false
               $gerente = $this->controlePedidoColetaInternetService->selectEGerente($row[0]['OPERADORLOGADO']);
               
               //Verifica se o operador é o comprador dos pedidos a serem aceitos
               $comprador = true;
               foreach ($row as $pedido){
                    
                   if($pedido['CDOPERLANC'] != $row[0]['OPERADORLOGADO']){
                       $comprador = false;
                   }
               }
    
               switch ($paramUsaApMassa){
                   case "N":
                       //Verificar quantos pedidos chegaram
                       if(count($row) == 1){
                           //se for 1 OK
                           $response->addMessage(new DTO\Response\Message('OK'));
                       }else{
                           //se for maior que 1 erro
                           $response->addMessage(new DTO\Response\Message('ERROR_1'));
                       }
                    break;
                    case "A":
                        if($gerente == "1" || $comprador){
                            $response->addMessage(new DTO\Response\Message('OK'));
                        }else{
                            $response->addMessage(new DTO\Response\Message('ERROR'));
                        }
                    break;
                    case "G":
                        //verifica se é gerente
                        if($gerente == "1"){
                            $response->addMessage(new DTO\Response\Message('OK'));
                        }else{
                            $response->addMessage(new DTO\Response\Message('ERROR'));
                        }
                    break;
                    case "C":
                        if($comprador){
                            $response->addMessage(new DTO\Response\Message('OK'));
                        }else{
                            $response->addMessage(new DTO\Response\Message('ERROR'));
                        }
                    break;
               }
          
            }
		} catch (\Exception $e) {
		   $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(),500));
		}
    }
    
    public function verificaFuncionalidadeEnvEmail(DTO\Request\Row $request, DTO\Response $response) {
        $row = $request->getRow();
        try {
            $possuiMsg =    $this->controlePedidoColetaInternetService->selectMsgEnvEmail($row['FUNCIONALIDADE']);
            if(!$possuiMsg){
                $response->addMessage(new DTO\Response\Message('FALSE'));
            }else{
                
                //$possuiMsg[0]['DSBODY'] = $this->setMnemonico($row['DADOS'],$possuiMsg[0]['DSBODY']);
                
                $response->addMessage(new DTO\Response\Message($possuiMsg));
            }
		} catch (\Exception $e) {
		   $response->setError(new \Zeedhi\Framework\DTO\Response\Error($e->getMessage(),500));
		}
    }
    
        public function getMensagemEnvioEmail(DTO\Request\Row $request, DTO\Response $response)
    {
        $row = $request->getRow();
        try {
            
            $aux = false;
            if($row["OPERACAO"] == 'ALTERAR_VALIDADE'){
                $idoperacao = 'V';
                $aux = true;
            }
            if($row["OPERACAO"] == 'ALTERAR_EXPIRACAO'){
                $idoperacao = 'E';
                $aux = true;
            }
            if($row["OPERACAO"] == 'RETORNAR'){
                $idoperacao = 'N';
                $aux = true;
            }
            if($aux){
                $query = "SELECT DSSUBJECT, DSBODY   FROM MENSAGEMPADRAOEMAIL WHERE IDOPERACAO = :P_IDOPERACAO  AND NRORG = :P_NRORG AND IDATIVO = 'S'";
                $params = [
                    "P_NRORG"=> $this->environment->getNrOrg(),
                    "P_IDOPERACAO"=> $idoperacao
                ];
    
                $resp =  $this->supUtilities->crud($query, $params);
                
                //substitui os mnemonicos
                /*if($resp){
                    $resp[0]['DSBODY'] = $this->setMnemonico($row['DADOS'],$resp[0]['DSBODY']);
                }
                */
            }else{
                $resp = [];
            }
            $response->addMessage(new DTO\Response\Message($resp));
            
        } catch(Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }
    
    public function setMnemonico($row, $msg)// param de entrada: row
    {
        // buscar se tem o mnemonico no texto usando strpos($string, 'nome_do_mnemonico') !== false
        // caso o if condicional for true, substituir no texto com str_replace('nome_do_mnemonico', 'valor_do_mnemonico', $string);
        $query2 = "select NRINSJURFORN, NMFANTFORN, NMRAZSOCFORN from fornecedor where CDFORNECED = :CDFORNECED AND NRORG = :P_NRORG";
        $params2 = [
                    "P_NRORG"=> $this->environment->getNrOrg(),
                    "CDFORNECED"=> $row[1]['CDFORNECED']
                ];
    
        $resp2 =  $this->supUtilities->crud($query2, $params2)[0];
        $query3 = "select DTPEDCOLETA, DTFINPERCOT from PEDCOLETA WHERE NRPEDCOLETA = :NRPEDCOLETA  AND NRORG = :P_NRORG";
        $params3 = [
                    "P_NRORG"=> $this->environment->getNrOrg(),
                    "NRPEDCOLETA"=> $row[1]['NRPEDCOLETA']
                ];
    
        $resp3 =  $this->supUtilities->crud($query3, $params3)[0];
                
       
        
        if(strpos($msg, 'CNPJ_CPF') !== false){
            $msg = str_replace('CNPJ_CPF', $resp2['NRINSJURFORN'] , $msg);
        }
        if(strpos($msg, 'NM_FANTFORN') !== false){
           $msg = str_replace('NM_FANTFORN', $resp2['NMFANTFORN'], $msg);
        }
        if(strpos($msg, 'NM_RAZSFORN') !== false){
            $msg = str_replace('NM_RAZSFORN', $resp2['NMRAZSOCFORN'], $msg);
        }
        if(strpos($msg, 'NR_PEDIDO') !== false){
            $msg = str_replace('NR_PEDIDO', $row[1]['NRPEDCOLETA'], $msg);
        }
        if(strpos($msg, 'COD_REGIAO') !== false){
            $msg = str_replace('COD_REGIAO', $row[1]['CDREGIAO'], $msg);
        }
        if(strpos($msg, 'NM_REGIAO') !== false){
            $msg = str_replace('NM_REGIAO', $row[1]['NMREGIAO'], $msg);
        }
        if(strpos($msg, 'NM_OPERADOR') !== false){
            $msg = str_replace('NM_OPERADOR', $row[1]['NMCOMPRADOR'], $msg);
        }
        //if(strpos($msg, 'URL_PORTAL') !== false){
        //    $msg = str_replace('URL_PORTAL', 'valor_do_mnemonico', $msg);
        //}
        if(strpos($msg, 'DT_GERACAO') !== false){
            $msg = str_replace('DT_GERACAO', $resp3['DTPEDCOLETA'], $msg);
        }
        if(strpos($msg, 'DT_VALIDADE') !== false){
            $msg = str_replace('DT_VALIDADE', $resp3['DTFINPERCOT'], $msg);
        }
        if(strpos($msg, 'DT_EXPIRACAO') !== false){
            $msg = str_replace('DT_EXPIRACAO', $row[1]['DTEXPIRAPEDCOL'], $msg);
        }
        if(strpos($msg, 'JUST_DELETE') !== false){
            $msg = str_replace('JUST_DELETE', $row['JUSTIFICATIVA'], $msg);
        }
        return $msg;
    }
    
    public function getCDFILCENTCMP() {
        $query = "SELECT NVL(CDFILCENTCMP, CDFILIAL) AS CDFILCENTCMP FROM FILIAL WHERE (CDFILIAL = :CDFILIAL)";
        $params = [
            "CDFILIAL"=> $this->environment->getCdFilial()
        ];
        $result =  $this->supUtilities->crud($query, $params);
        return $result[0]['CDFILCENTCMP'];
    }
    
     public function getURLPortal(DTO\Request\Row $request, DTO\Response $response)
    {
        try {
            $query = "SELECT DSLINKECOMMERCE FROM PARAMGERALECOMMERCE WHERE CDFILIAL = :P_CDFILIAL AND NRORG = :P_NRORG";
            $params = [
                "P_CDFILIAL"=> $this->getCDFILCENTCMP(),
                "P_NRORG"   => $this->environment->getNrOrg()
            ];
            $result =  $this->supUtilities->crud($query, $params);
            $resp = isset($result[0]['DSLINKECOMMERCE']) ? $result[0]['DSLINKECOMMERCE'] : '';
            $response->addMessage(new DTO\Response\Message($resp));
        } catch(Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
    }

}